# docker_mailserver

Installation de mailserver sur un serveur docker_host, en lien avec un annuaire LDAP.

## Prérequis

* un serveur préparé avec rôle docker_host
* un annuaire LDAP préparé avec le role docker_openldap


## Variables

Fournir les variables suivantes. Par exemple :

```yaml
# Le nom de domaine pour lequel le service mailserver répond
docker_mailserver_fqdn: mailserver.example.com
# Version de l'image docker pour mailserver
docker_mailserver_version: 13.2.0
# L'emplacement dans lequel se trouvent les volumes de donnees docker pour le service
docker_mailserver_data_dir: /data1
# Le nom de service souhaité : conditionne le nommage des volumes
docker_mailserver_service_id: mailserver
# Adresse du postmaster
docker_mailserver_postmaster_address: postmaster@example.com
```

Si le conteneur docker_mailserver ne doit pas écouter sur toutes les interfaces, il est possible de spécifier les adresses d'écoute avec ces variables :

```yaml
docker_mailserver_listen_ipv4: "1.2.3.4"
docker_mailserver_listen_ipv6: "2345:425:1234::1234"
```


Si couplage avec un annuaire LDAP, définir à minima les variables suivantes :

```yaml
# URI du serveur LDAP
docker_mailserver_ldap_server: ldaps://ldap.example.com:636
# Base de recherche LDAP
docker_mailserver_ldap_search_base: "dc=example,dc=com"
# DN du compte de service de connexion à l'annuaire
docker_mailserver_ldap_bind_dn: "uid=mailserver,ou=serviceaccounts,dc=example,dc=com"
# Mot de passe du compte de service
docker_mailserver_ldap_bind_pwd: mypassword
```

D'autres variables ont des valeurs par défaut qu'il est possible de surchrager et qui sont présentes dans defaults/main.yml.


Consulter https://docker-mailserver.github.io/docker-mailserver/latest/ pour les détails des options de configuration


## Dépendances

Aucune


## Exemple de playbook

```yaml
- hosts: all

  vars:
    docker_mailserver_fqdn: mail.example.com
    docker_mailserver_data_dir: /data/my-docker-mailserver-volume
    docker_mailserver_service_id: mailserver_mail_example_com
    docker_mailserver_version: 13.1.0
    docker_mailserver_listen_ipv4: 1.2.3.4
    docker_mailserver_ldap_server: "ldaps://ldap.example.com:636"
    docker_mailserver_ldap_search_base: "dc=example,dc=com"
    docker_mailserver_ldap_bind_dn: "uid=mailserver,ou=serviceaccounts,dc=example,dc=com"
    docker_mailserver_ldap_bind_pwd: !vault |
              $ANSIBLE_VAULT;1.1;AES256
              1234567890123456789012345678901234567890123456789012345678901234567890
              12345678901234567890123456789

  roles:
    - docker_mailserver
```

# Licence

MIT
